# -*- coding: utf-8 -*-

from setuptools import setup
from fresh._version import __version__


setup(name="fresh",
      version=__version__,
      author="Miles Granger",
      maintainer='Miles Granger',
      author_email='miles59923@gmail.com',
      maintainer_email='miles59923@gmail.com',
      keywords='automated machine learning',
      description='Automated, end-to-end machine learning',
      long_description='',
      packages=['fresh'],
      license='BSD',
      url='https://github.com/milesgranger/fresh',
      zip_safe=False,
      setup_requires=['pytest-runner'],
      install_requires=[],
      tests_require=['pytest'],
      test_suite='tests',
      include_package_data=True,
      classifiers=[
            'Development Status :: 3 - Alpha',
            'Intended Audience :: Developers',
            'Intended Audience :: Financial and Insurance Industry',
            'Intended Audience :: Information Technology',
            'Intended Audience :: Science/Research',
            'Programming Language :: Python',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'Programming Language :: Python :: 3 :: Only',
            'Programming Language :: Rust',
            'Operating System :: Microsoft :: Windows',
            'Operating System :: POSIX',
            'Operating System :: Unix',
            'Operating System :: MacOS :: MacOS X',
      ],
)



# -*- coding: utf-8 -*-

import logging
from sklearn.base import BaseEstimator
from fresh.pipeline import PipeBuilder


class Model(BaseEstimator):
    """
    Basically a wrapper around .pipeline which handles the actual transformation and training of the model.
    This serves as a transparent wrapper to the raw data and following construction and training of multiple models
    and variations to find the best one.
    """

    target = None
    pipeline = None
    logger = logging.getLogger(__name__)

    def fit(self, X, y):
        if y.name in X.columns:
            self.logger.warning('Found target columns "{}" in X, deleting it!'.format(y.name))
            del X[y.name]
        self.pipeline = PipeBuilder.from_data(X, y)
        self.pipeline.fit(X, y)
        return self

    def predict(self, X):
        return self.pipeline.predict(X)

    def score(self, X, y, *args, **kwargs):
        return self.pipeline.score(X, y, *args, **kwargs)
